# traycer
__a python ray tracer__

![traycer](traycer.png)

Traycer is a basic ray tracer developed in python, following the C++ tutorial, [_Ray Tracing in One Weekend_](https://raytracing.github.io/books/RayTracingInOneWeekend.html). I'm not developing this because I think it is useful. It's just a project for fun/learning.

See [demo.ipynb](https://github.com/bpops/traycer/blob/main/demo.ipynb) for examples of use.